numpy.polynomial.HermiteE
=========================

.. currentmodule:: numpy.polynomial

.. autoclass:: HermiteE

   

   .. HACK
      .. autosummary::
         :toctree:
      
         HermiteE.__init__
         HermiteE.convert
         HermiteE.copy
         HermiteE.cutdeg
         HermiteE.degree
         HermiteE.deriv
         HermiteE.has_samecoef
         HermiteE.has_samedomain
         HermiteE.has_samewindow
         HermiteE.integ
         HermiteE.linspace
         HermiteE.mapparms
         HermiteE.roots
         HermiteE.trim
         HermiteE.truncate



   

